@@ -28,7 +28,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "4.0.2"
+__version__ = "4.0.3"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_BLE_File_Transfer.git"
 
 CHUNK_SIZE = 490
@@ -65,7 +65,7 @@ class _TransferCharacteristic(ComplexCharacteristic):
             fixed_length=False,
         )
 
-    def bind(self, service: Service) -> _bleio.PacketBuffer:
+    def bind(self, service: "FileTransferService") -> _bleio.PacketBuffer:
         """Binds the characteristic to the given Service."""
         bound_characteristic = super().bind(service)
         return _bleio.PacketBuffer(
